lilypondfiletools.DateTimeToken
===============================

.. inheritance-diagram:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken
   :private-bases:

.. autoclass:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken.format

Special Methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken.__eq__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken.__repr__

.. automethod:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken.__str__

   .. note:: Inherited from `__builtin__.object`
